@@ -16,6 +16,7 @@ iana_uri_schemes_other = {
     "gemini": "Gemini protocol",
     "isbn": "ISBN (int. book numbers)",
     "javascript": "JavaScript",
+    "ms-windows-store": "Microsoft Store",
     "slack": "Slack Technologies client",
     "tg": "Telegram",
     "whatsapp": "WhatsApp",
@@ -27,8 +28,6 @@ filter_uri_schemes_permanent = (
     "http",
     "https",
     "mailto",
-    "news",
-    "nntp",
 )
 
 template = '''
@@ -49,7 +48,7 @@ ignored_schemes_other = r"""
 %(other)s
 """
 
-ignored_schemes = "^(%%s%%s%%s%%s)$" %% (
+ignored_schemes = "^({}{}{}{})$".format(
     ignored_schemes_permanent,
     ignored_schemes_provisional,
     ignored_schemes_historical,
