@@ -367,10 +367,10 @@ class TestUrl(unittest.TestCase):
         url = "javascript:loadthis()"
         nurl = url
         self.urlnormtest(url, nurl)
-        # ldap url # XXX failing on Travis build
-        # url = "ldap://[2001:db8::7]/c=GB?objectClass?one"
-        # nurl = "ldap://%5B2001:db8::7%5D/c=GB?objectClass?one"
-        # self.urlnormtest(url, nurl)
+        # ldap url
+        url = "ldap://[2001:db8::7]/c=GB?objectClass?one"
+        nurl = "ldap://%5B2001:db8::7%5D/c=GB?objectClass?one"
+        self.urlnormtest(url, nurl)
         url = "tel:+1-816-555-1212"
         nurl = url
         self.urlnormtest(url, nurl)
